abacusai.eda_collinearity — AbacusAI documentation

# abacusai.eda_collinearity

## Classes

`EdaCollinearity` | Eda Collinearity of the latest version of the data between all the features.

## Module Contents

class abacusai.eda_collinearity.EdaCollinearity(client, columnNames=None, collinearityMatrix=None, groupFeatureDict=None, collinearityGroups=None, columnNamesX=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Eda Collinearity of the latest version of the data between all the features.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - columnNames (list) – Name of all the features in the y axis of the collinearity matrix

    - collinearityMatrix (dict) – A dict describing the collinearity between all the features

    - groupFeatureDict (dict) – A dict describing the index of the group from collinearity_groups a feature exists in

    - collinearityGroups (list) – Groups created based on a collinearity threshold of 0.7

    - columnNamesX (list) – Name of all the features in the x axis of the collinearity matrix

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict